==> plantuml-libs-5.2.0.tgz: package/distribution/aws-20210730/Resource/Compute/AwsElasticBeanstalkDeployment.md <==
# AwsElasticBeanstalkDeployment


```text
aws-20210730/Resource/Compute/AwsElasticBeanstalkDeployment
```

```text
include('aws-20210730/Resource/Compute/AwsElasticBeanstalkDeployment')
```



| Illustration | AwsElasticBeanstalkDeployment | AwsElasticBeanstalkDeploymentCard | AwsElasticBeanstalkDeploymentGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/Compute/AwsElasticBeanstalkDeployment.png) | ![illustration for AwsElasticBeanstalkDeployment](../../../aws-20210730/Resource/Compute/AwsElasticBeanstalkDeployment.Local.png) | ![illustration for AwsElasticBeanstalkDeploymentCard](../../../aws-20210730/Resource/Compute/AwsElasticBeanstalkDeploymentCard.Local.png) | ![illustration for AwsElasticBeanstalkDeploymentGroup](../../../aws-20210730/Resource/Compute/AwsElasticBeanstalkDeploymentGroup.Local.png) |




## AwsElasticBeanstalkDeployment

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsElasticBeanstalkDeployment
include('aws-20210730/Resource/Compute/AwsElasticBeanstalkDeployment')

' renders the element
AwsElasticBeanstalkDeployment('AwsElasticBeanstalkDeployment', 'Aws Elastic Beanstalk Deployment', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsElasticBeanstalkDeployment
include('aws-20210730/Resource/Compute/AwsElasticBeanstalkDeployment')

' renders the element
AwsElasticBeanstalkDeployment('AwsElasticBeanstalkDeployment', 'Aws Elastic Beanstalk Deployment', 'an optional tech label')
@enduml
```

## AwsElasticBeanstalkDeploymentCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsElasticBeanstalkDeploymentCard
include('aws-20210730/Resource/Compute/AwsElasticBeanstalkDeployment')

' renders the element
AwsElasticBeanstalkDeploymentCard('AwsElasticBeanstalkDeploymentCard', 'Aws Elastic Beanstalk Deployment Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsElasticBeanstalkDeploymentCard
include('aws-20210730/Resource/Compute/AwsElasticBeanstalkDeployment')

' renders the element
AwsElasticBeanstalkDeploymentCard('AwsElasticBeanstalkDeploymentCard', 'Aws Elastic Beanstalk Deployment Card', 'an optional description')
@enduml
```

## AwsElasticBeanstalkDeploymentGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsElasticBeanstalkDeploymentGroup
include('aws-20210730/Resource/Compute/AwsElasticBeanstalkDeployment')

' renders the element
AwsElasticBeanstalkDeploymentGroup('AwsElasticBeanstalkDeploymentGroup', 'Aws Elastic Beanstalk Deployment Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsElasticBeanstalkDeploymentGroup
include('aws-20210730/Resource/Compute/AwsElasticBeanstalkDeployment')

' renders the element
AwsElasticBeanstalkDeploymentGroup('AwsElasticBeanstalkDeploymentGroup', 'Aws Elastic Beanstalk Deployment Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-6.4.0.tgz: package/distribution/aws-20210730/Resource/Compute/AwsElasticBeanstalkDeployment.md <==
# AwsElasticBeanstalkDeployment


```text
aws-20210730/Resource/Compute/AwsElasticBeanstalkDeployment
```

```text
include('aws-20210730/Resource/Compute/AwsElasticBeanstalkDeployment')
```



| Illustration | AwsElasticBeanstalkDeployment | AwsElasticBeanstalkDeploymentCard | AwsElasticBeanstalkDeploymentGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/Compute/AwsElasticBeanstalkDeployment.png) | ![illustration for AwsElasticBeanstalkDeployment](../../../aws-20210730/Resource/Compute/AwsElasticBeanstalkDeployment.Local.png) | ![illustration for AwsElasticBeanstalkDeploymentCard](../../../aws-20210730/Resource/Compute/AwsElasticBeanstalkDeploymentCard.Local.png) | ![illustration for AwsElasticBeanstalkDeploymentGroup](../../../aws-20210730/Resource/Compute/AwsElasticBeanstalkDeploymentGroup.Local.png) |




## AwsElasticBeanstalkDeployment

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsElasticBeanstalkDeployment
include('aws-20210730/Resource/Compute/AwsElasticBeanstalkDeployment')

' renders the element
AwsElasticBeanstalkDeployment('AwsElasticBeanstalkDeployment', 'Aws Elastic Beanstalk Deployment', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsElasticBeanstalkDeployment
include('aws-20210730/Resource/Compute/AwsElasticBeanstalkDeployment')

' renders the element
AwsElasticBeanstalkDeployment('AwsElasticBeanstalkDeployment', 'Aws Elastic Beanstalk Deployment', 'an optional tech label')
@enduml
```

## AwsElasticBeanstalkDeploymentCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsElasticBeanstalkDeploymentCard
include('aws-20210730/Resource/Compute/AwsElasticBeanstalkDeployment')

' renders the element
AwsElasticBeanstalkDeploymentCard('AwsElasticBeanstalkDeploymentCard', 'Aws Elastic Beanstalk Deployment Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsElasticBeanstalkDeploymentCard
include('aws-20210730/Resource/Compute/AwsElasticBeanstalkDeployment')

' renders the element
AwsElasticBeanstalkDeploymentCard('AwsElasticBeanstalkDeploymentCard', 'Aws Elastic Beanstalk Deployment Card', 'an optional description')
@enduml
```

## AwsElasticBeanstalkDeploymentGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsElasticBeanstalkDeploymentGroup
include('aws-20210730/Resource/Compute/AwsElasticBeanstalkDeployment')

' renders the element
AwsElasticBeanstalkDeploymentGroup('AwsElasticBeanstalkDeploymentGroup', 'Aws Elastic Beanstalk Deployment Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsElasticBeanstalkDeploymentGroup
include('aws-20210730/Resource/Compute/AwsElasticBeanstalkDeployment')

' renders the element
AwsElasticBeanstalkDeploymentGroup('AwsElasticBeanstalkDeploymentGroup', 'Aws Elastic Beanstalk Deployment Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
